#ifndef INFOBOX_H
#define INFOBOX_H

enum
{
    JUSTIFY_LEFT=GTK_JUSTIFY_LEFT,
    JUSTIFY_RIGHT,
    JUSTIFY_CENTER
};
enum
{
    VERT_NONE,
    VERT_TOP,
    VERT_MIDDLE,
    VERT_BOTTOM
};
enum
{
    HORIZ_NONE,
    HORIZ_LEFT,
    HORIZ_CENTER,
    HORIZ_RIGHT
};
enum
{
    SIZE_NONE,
    SIZE_PIXEL,
    SIZE_PERCENT
};
enum
{
    TIMEOUT_BELOW,
    TIMEOUT_HIDE
};
enum
{
    CFG_BOOLEAN,
    CFG_INTEGER,
    CFG_STRING,
    CFG_TINTCOLOR,
    CFG_SIZETYPE,
    CFG_JUSTIFY,
    CFG_GDKCOLOR,
    CFG_FONT,
    CFG_HORIZ,
    CFG_VERT,
    CFG_AFTERTIMEOUT
};
enum
{
    NOTIFY_EXPIRED=1,
    NOTIFY_DISSMISED,
    NOTIFY_CLOSENOTIFY,
    NOTIFY_UNDEFINED
};
enum
{
    WINDOW_ABOVE,
    WINDOW_HIDE,
    WINDOW_BELOW
};

typedef struct {
	GtkWidget *gwin;    // main window
	GtkWidget *bbox;	// background box
	GtkWidget *ebox;	// event box
	GtkWidget *vbox;	// vertical box
	GtkWidget *h1box;	// horizontal box for time, icon and title
	GtkWidget *h2box;	// horizontal box for image, and body
	GtkWidget *time;	// msg's time
	GtkWidget *icon;	// icon 
	GtkWidget *title;	// title lable
	GtkWidget *vimgbox; // vertical box for icon
    GtkWidget *image;	// image
	GtkWidget *body;	// body label

    FbBg *bg;
    gint alpha;
    gboolean transparncy;
    guint32 tintcolor, hilighttintcolor;

    gint geomx, geomy;
    gint cx, cy, cw, ch;  // current allocation (as reported by configure event) allocation
    gint widthtype, width, widthmin, widthmax;
    gint heighttype, height, heightmin, heightmax;
    gint vert, horiz, xoffset, yoffset;

    gint borderwidth;
    GdkColor bordercolor;

    gint iconsize; // size of theme icon
    gint imagehmax, imagewmax; // max width and height of image (-1 to no bounds; 0 to not showing)

    gint textjustify;
    PangoFontDescription *textfont;
    GdkColor textcolor;

    gint windowstate;

    guint32 notifyid;
    gboolean notifyhided;

    gint timeout, timeoutid, aftertimeout;

    gboolean urlclicked;

    DBusConnection *dbusconn;
} InfoBox;

InfoBox ib;

typedef struct {
	gchar *key;
	gint type;
	gchar *val;
} cfg;

cfg configtable[]={
    {"Transparency", CFG_BOOLEAN, (gchar *) &ib.transparncy},
    {"Alpha", CFG_INTEGER, (gchar *) &ib.alpha},
    {"TintColor", CFG_TINTCOLOR, (gchar *) &ib.tintcolor},
    {"HilightTintColor", CFG_TINTCOLOR, (gchar *) &ib.hilighttintcolor},
    {"XGeom", CFG_INTEGER, (gchar *) &ib.geomx},
    {"YGeom", CFG_INTEGER, (gchar *) &ib.geomy},
    {"WidthType", CFG_SIZETYPE, (gchar *) &ib.widthtype},
    {"Width", CFG_INTEGER, (gchar *) &ib.width},
    {"WidthMin", CFG_INTEGER, (gchar *) &ib.widthmin},
    {"WidthMax", CFG_INTEGER, (gchar *) &ib.widthmax},
    {"HeightType", CFG_SIZETYPE, (gchar *) &ib.heighttype},
    {"Height", CFG_INTEGER, (gchar *) &ib.height},
    {"HeightMin", CFG_INTEGER, (gchar *) &ib.heightmin},
    {"HeightMax", CFG_INTEGER, (gchar *) &ib.heightmax},
    {"TextJustify", CFG_JUSTIFY, (gchar *) &ib.textjustify},
    {"TextColor", CFG_GDKCOLOR, (gchar *) &ib.textcolor},
    {"TextFont", CFG_FONT, (gchar *) &ib.textfont},
    {"Horizontal", CFG_HORIZ, (gchar *) &ib.horiz},
    {"Vertical", CFG_VERT, (gchar *) &ib.vert},
    {"XOffset", CFG_INTEGER, (gchar *) &ib.xoffset},
    {"YOffset", CFG_INTEGER, (gchar *) &ib.yoffset},
    {"BorderWidth", CFG_INTEGER, (gchar *) &ib.borderwidth},
    {"BorderColor", CFG_GDKCOLOR, (gchar *) &ib.bordercolor},
    {"ThemeIconSize", CFG_INTEGER, (gchar *) &ib.iconsize},
    {"ImageWidthMax", CFG_INTEGER, (gchar *) &ib.imagewmax},
    {"ImageHeightMax", CFG_INTEGER, (gchar *) &ib.imagehmax},
    {"Timeout", CFG_INTEGER, (gchar *) &ib.timeout},
    {"AfterTimeout", CFG_AFTERTIMEOUT, (gchar *) &ib.aftertimeout}
};

static gchar *transparent_rc="style 'transparent-style'\n"
"{\n"
"bg_pixmap[NORMAL] = \"<parent>\"\n"
"bg_pixmap[INSENSITIVE] = \"<parent>\"\n"
"bg_pixmap[PRELIGHT] = \"<parent>\"\n"
"bg_pixmap[SELECTED] = \"<parent>\"\n"
"bg_pixmap[ACTIVE] = \"<parent>\"\n"
//"fg[NORMAL] = \"#ffffff\"\n"
//"fg[ACTIVE] = \"#ffffff\"\n"
//"fg[SELECTED] = \"#ffffff\"\n"
"}\n"
"class \"GtkEventBox\" style \"transparent-style\"\n"
"class \"GtkLabel\" style \"transparent-style\"\n";

static void ib_gui_notify_show(GdkPixbuf *icon, gchar *title, gchar* body, GdkPixbufAnimation *image, gint timeout);
static void ib_gui_notify_hide(gint how, gint reason);
static GdkPixbuf *ib_gui_load_image(guchar *data, gboolean raw, gint len, gint scaledwidth, gint scaledheight);
static gboolean ib_gui_callback_timeout(gpointer data);
static gint ib_gui_calculate_width(gint width);
static gint ib_gui_calculate_height(gint height);
static void ib_dbus_hide_notify(gint reason);
static void ib_config_parser(GKeyFile *keyfile, gchar *group, gchar **keys);
static void ib_config_setup_gui(void);
static gint ib_config_strcmp(gchar *string1, gchar *string2);

#endif

